==> allure-0.11.0.0-303-riscv64.pkg.tar.zst: usr/share/haskell/register/allure.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Allure
version:              0.11.0.0
visibility:           public
id:                   Allure-0.11.0.0-JnzYhM4XvXS6FxQmQg2pw4
key:                  Allure-0.11.0.0-JnzYhM4XvXS6FxQmQg2pw4
license:              AGPL-3.0-or-later
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Andres Loeh, Mikolaj Konarski and others
homepage:             http://allureofthestars.com
synopsis:             Near-future Sci-Fi roguelike and tactical squad combat game
description:
    Allure of the Stars is a near-future Sci-Fi roguelike
    and tactical squad combat game. Binaries and the game manual
    are available at the homepage. You can also try the game out
    in the browser at <http://allureofthestars.com/play>.

    Not a single image in this game. You have to imagine everything
    yourself, like with a book (a grown-up book, without pictures).
    Once you learn to imagine things, though, you can keep exploring
    and mastering the world and making up stories for a long time.

    The game is written in Haskell using the LambdaHack roguelike
    game engine <http://hackage.haskell.org/package/LambdaHack>.
    Please see the changelog file for recent improvements
    and the issue tracker for short-term plans. Long term goals
    are high replayability and auto-balancing through procedural
    content generation and persistent content modification
    based on player behaviour. Contributions are welcome.

    This is a workaround .cabal file, flattened to eliminate
    internal libraries until generating haddocks for them
    is fixed. The original .cabal file is in .cabal.bkp file.

category:             Game
abi:                  400f859067055535a6b0dc41f104c169
exposed:              True
exposed-modules:
    Client.UI.Content.Input Client.UI.Content.Screen Content.CaveKind
    Content.FactionKind Content.ItemKind Content.ItemKindActor
    Content.ItemKindBlast Content.ItemKindEmbed Content.ItemKindOrgan
    Content.ItemKindTemporary Content.ModeKind Content.PlaceKind
    Content.RuleKind Content.TileKind
    Implementation.MonadClientImplementation
    Implementation.MonadServerImplementation TieKnot

hidden-modules:       Paths_Allure
import-dirs:          /usr/lib/ghc-9.4.8/site-local/Allure-0.11.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/Allure-0.11.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/Allure-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/allure
hs-libraries:         HSAllure-0.11.0.0-JnzYhM4XvXS6FxQmQg2pw4
depends:
    LambdaHack-0.11.0.1-F8Z6QyWFL81wynmUIJdET
    async-2.2.5-GGvJE1nOBFYGFw0FXsPFU0 base-4.17.2.1
    enummapset-0.7.3.0-IsIkPK0KuYVFgMzAUWSNFS
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    ghc-compact-0.1.0.0 hsini-0.5.2.2-CuOseWndpC3GSFrVLKiiyY
    optparse-applicative-0.18.1.0-t4C6chS8YH5x9x9VuRkT0
    primitive-0.9.1.0-1TuYyil4nabJdMHni5vWH
    splitmix-0.1.2-Chrz8zvxTCsBSY3wfrtNYj template-haskell-2.19.0.0
    text-2.0.2 th-lift-instances-0.1.20-HSRjlGXAGtLJZoUMZdls5z
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/allure/html/Allure.haddock
haddock-html:         /usr/share/doc/allure/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> allure-0.11.0.0-310-riscv64.pkg.tar.zst: usr/share/haskell/register/allure.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Allure
version:              0.11.0.0
visibility:           public
id:                   Allure-0.11.0.0-2QZryw4u7KoAnWdWZrhbZX
key:                  Allure-0.11.0.0-2QZryw4u7KoAnWdWZrhbZX
license:              AGPL-3.0-or-later
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Andres Loeh, Mikolaj Konarski and others
homepage:             http://allureofthestars.com
synopsis:             Near-future Sci-Fi roguelike and tactical squad combat game
description:
    Allure of the Stars is a near-future Sci-Fi roguelike
    and tactical squad combat game. Binaries and the game manual
    are available at the homepage. You can also try the game out
    in the browser at <http://allureofthestars.com/play>.

    Not a single image in this game. You have to imagine everything
    yourself, like with a book (a grown-up book, without pictures).
    Once you learn to imagine things, though, you can keep exploring
    and mastering the world and making up stories for a long time.

    The game is written in Haskell using the LambdaHack roguelike
    game engine <http://hackage.haskell.org/package/LambdaHack>.
    Please see the changelog file for recent improvements
    and the issue tracker for short-term plans. Long term goals
    are high replayability and auto-balancing through procedural
    content generation and persistent content modification
    based on player behaviour. Contributions are welcome.

    This is a workaround .cabal file, flattened to eliminate
    internal libraries until generating haddocks for them
    is fixed. The original .cabal file is in .cabal.bkp file.

category:             Game
abi:                  b665a4148ba296f7357b4b4f3df0d5a1
exposed:              True
exposed-modules:
    Client.UI.Content.Input Client.UI.Content.Screen Content.CaveKind
    Content.FactionKind Content.ItemKind Content.ItemKindActor
    Content.ItemKindBlast Content.ItemKindEmbed Content.ItemKindOrgan
    Content.ItemKindTemporary Content.ModeKind Content.PlaceKind
    Content.RuleKind Content.TileKind
    Implementation.MonadClientImplementation
    Implementation.MonadServerImplementation TieKnot

hidden-modules:       Paths_Allure
import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/Allure-0.11.0.0
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/Allure-0.11.0.0
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/Allure-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/allure
hs-libraries:         HSAllure-0.11.0.0-2QZryw4u7KoAnWdWZrhbZX
depends:
    LambdaHack-0.11.0.1-LRq326kLFcW3sLgqlWViHT
    async-2.2.5-1ovq96REeQVKYsP5cduurl base-4.18.3.0
    enummapset-0.7.3.0-J9SKno0Gu4E3mLO4sXESOV
    file-embed-0.0.16.0-Heqv1MGULDp1AU5LH7qKhb filepath-1.4.301.0
    ghc-compact-0.1.0.0 hsini-0.5.2.2-HlYr2LTnKlySbKSUmwNYd
    optparse-applicative-0.18.1.0-BYVre8yzbBOKektbxJ0fjC
    primitive-0.9.1.0-GYJhpUEcsq4755gfDRC2m0
    splitmix-0.1.3-7P935sgOm5yAEYIwa4ipc3 template-haskell-2.20.0.0
    text-2.0.2 th-lift-instances-0.1.20-7KoUyeRUuPc8QOCwNKMZFK
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/allure/html/Allure.haddock
haddock-html:         /usr/share/doc/allure/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
